Features — rabbitChat 1.0.0 documentation

# Features

## Technical Specs

sockjs-client: | Advanced Websocket Javascript Clien
Tornado: | Async Python Web Library + Web Server
sockjs-tornado: | SockJS websocket server implementation for Tornado
AMQP: | Advance Message Queuing Protocol used in Message Oriented Middleware
pika: | AMQP Python Client Library
RabbitMQ: | A Message Broker implementing AMQP

## Feature Specs

- Public chat
- Shows who joined and who left
- Shows number of people online
- Shows who is typing and who is not
- Join/Leave chat room features